/**
  *  \file client/playvcropts.h
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_PLAYVCROPTS_H
#define PCC_V2_CLIENT_PLAYVCROPTS_H

#include "util/cmdline.h"

/** Option Parser for playvcr. */
class PlayvcrOptionParser : public StandardCommandLineParser {
 public:
    enum Mode {
        mUnset,
        mPlayFile,              // Play or simulate a file. arg0 is file, arg1 is directory. Optional battle number says play that.
        mChooseFile,            // Choose a file.
        mSimulate               // Simulate.
    };
    PlayvcrOptionParser();
    void handleNonoption(const string_t& str);
    void handleError(const string_t& msg);
    int getNumNonoptions() const { return num_nonoptions; }
    int getBattleNumber() const { return battle_nr; }
    void setBattleNumber(int n) { battle_nr = n; }
    void parseFinished();

    void setFileName(const string_t& s) { nonopts[0] = s; }
    void setDirName(const string_t& s) { nonopts[1] = s; }

    string_t getFileName() const { return nonopts[0]; }
    string_t getDirName() const { return nonopts[1]; }

    Mode getMode() const { return mode; }
    void setMode(Mode m) { mode = m; }

 private:
    Mode mode;
    enum {
        MAX_NON_OPTIONS = 2
    };
    int num_nonoptions;
    string_t nonopts[MAX_NON_OPTIONS];
    int battle_nr;

    static void help(StandardCommandLineParser&, const Option&);
    static void setCharset(StandardCommandLineParser&, const Option&);
    static void setDirectoryMode(StandardCommandLineParser&, const Option&);
    static void setSimulatorMode(StandardCommandLineParser&, const Option&);
};

#endif
