/**
  *  \file client/tiles/histpostile.cc
  *  \brief WHistoryShipPositionTile tile
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/histpostile.h"
#include "client/screens/histscreen.h"
#include "game/ship.h"
#include "client/widgets/histposlist.h"
#include "util/nls.h"
#include "ui/util.h"

enum { NLINES = 10 };

/** Constructor.
    \param selection Object selection to observe. Should be a WHistoryObjectSelection
    (but doesn't have to). */
WHistoryShipPositionTile::WHistoryShipPositionTile(GObjectSelection& selection)
    : WTile(GfxPoint(315, (NLINES+1)*font_heights[FONT_NORMAL]+5)),
      GObjectSelectionObserver(selection),
      hot(dynamic_cast<WHistoryObjectSelection*>(&selection)),
      list(0)
{
    init();
}

void
WHistoryShipPositionTile::init()
{
    // Make sure we can receive focus
    setState(st_Disabled, false);

    // Default layout
    setLayout(LeftJustified, 5, true);

    // Create list
    list = &holder.add(new WHistoryShipPositionList(NLINES, 305));
    addControl(GfxRect(0, font_heights[FONT_NORMAL]+4, 305, font_heights[FONT_NORMAL]*NLINES), *list);
    list->sig_moved.add(this, &WHistoryShipPositionTile::onMove);
    list->setFocusedWidget();

    // Initialize list content
    onObjectChanged();

    // Accept changes on the list
    if (hot) {
        conn_turn = hot->sig_turn_changed.add(this, &WHistoryShipPositionTile::onTurnChange);
    }
}

void
WHistoryShipPositionTile::onMove()
{
    // Propagate turn number change to WHistoryObjectSelection
    if (hot) {
        hot->setTurn(list->getTurn());
    }
}

void
WHistoryShipPositionTile::onTurnChange()
{
    if (hot) {
        list->setTurn(hot->getTurn());
    }
}

void
WHistoryShipPositionTile::drawData(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setColor(UIColor::tc_Static);
    outText(ctx, 5, 0, _("Turn: Location"));
    ctx.setTextAlign(2, 0);
    outText(ctx, getExtent().w - 10, 0, _("Mass"));

    GfxRect r(list->getExtent());
    r.moveByRev(getExtent().x, getExtent().y);
    r.grow(1, 1);
    drawFrameDown(can, r);

    can.update(getExtent());
}

void
WHistoryShipPositionTile::onObjectChanged()
{
    // No need to redraw the tile, just update the list.
    list->setShip(dynamic_cast<GShip*>(getCurrentObject()));
}
