/**
  *  \file client/widgets/playerchoose.cc
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/playerchoose.h"

WPlayerChooser::WPlayerChooser(int id)
    : UIListbox(id, NUM_PLAYERS, 270, 0), available_players()
{
    setDirectory(0);
}

WPlayerChooser::~WPlayerChooser()
{ }

void
WPlayerChooser::addCommand(string_t name)
{
    commands.push_back(name);
    setSize(NUM_PLAYERS + commands.size());
    setDefaultHeight();
}

void
WPlayerChooser::setDirectory(Ptr<Directory> dir)
{
    /* first, read new race names */
    bool loaded = false;
    if (dir) {
        try {
            Ptr<Stream> s = dir->openFile("race.nm", Stream::C_READ);
            player_names.load(*s);
            loaded = true;
        }
        catch(...) { }
    }
    if (!loaded)
        player_names = ::player_racenames;
    for (int i = 0; i < NUM_PLAYERS; ++i)
        player_info[i].clear();

    /* now, scan directory */
    available_players = GPlayerSet();
    if (dir)
        scan(*dir);

    setTop(0);
    setSize(NUM_PLAYERS + commands.size());

    if (available_players.nonempty()) {
        setState(st_Disabled, false);
        scrollTo(0, 1);
        drawWidget(false);
    } else {
        setState(st_Disabled, true);
        drawWidget(false);
    }
}

void
WPlayerChooser::drawPart(GfxCanvas& can, int from, int to)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useFont(*fonts[FONT_NORMAL]);

    for (int line = from; line < to; ++line) {
        const int index = getTop() + line;
        GfxRect area;
        prepareEntry(ctx, HighContrastStyle, line, &area);
        if (index < getSize()) {
            string_t txt, info;
            if (index >= NUM_PLAYERS) {
                txt = commands[index-NUM_PLAYERS];
            } else {
                txt = player_names.getShortName(index+1);
                info = player_info[index];
            }
            if (info.length()) {
                outTextF(ctx, area.x + 10, area.y, area.w - 110, txt);
                outTextF(ctx, area.x + extent.w - 100, area.y, 100, info);
            } else {
                outTextF(ctx, area.x + 10, area.y, area.w - 10, txt);
            }
        }
    }
}

bool
WPlayerChooser::isAccessible(int index)
{
    if (index < NUM_PLAYERS)
        return available_players.contains(index+1);
    else
        return available_players.nonempty();
}

void
WPlayerChooser::getLayoutInfo(LayoutInfo& info)
{
    UIListbox::getLayoutInfo(info);
    info.min_size = info.pref_size;
    info.flags &= ~li_FlexibleV;
}

void
WPlayerChooser::setInfo(int player, bool avail, string_t text)
{
    if (avail)
        available_players += player;
    player_info[player-1] = text;
}

void
WPlayerChooser::onClick(int n)
{
    if (n < NUM_PLAYERS)
        sig_player.raise(n);
    else
        sig_command.raise(n - NUM_PLAYERS);
}
