/**
  *  \file client/widgets/scanresult.h
  *  \brief WScanResult widget
  *
  *  (c) 2001-2015 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_SCANRESULT_H
#define PCC_V2_CLIENT_WIDGETS_SCANRESULT_H

#include "ui/ui.h"
#include "cpluslib/sigslot.h"
#include "ui/widgets/button.h"

class WScannerChartWidget;

/** \class WScanResult
    \brief Scanner Evaluation

    This widget displays the result of a scan (distance, name of
    object pointed-to). It must, after construction, be associated
    with a WScannerChartWidget. */

class WScanResult : public UIBaseComplexWidget {
    WScannerChartWidget* chart;        ///< Associated, observed scanner chart widget.
    int sid;                           ///< Scanned ship Id, if any. 0 otherwise.
    int xpid;                          ///< Scanned exact planet Id, if any. 0 otherwise.
    int gpid;                          ///< Scanned gravity planet Id, if any. 0 otherwise.
    const bool with_buttons;           ///< true to show buttons.

    UIButton button_l;                 ///< "L" button.
    UIButton button_y;                 ///< "Y" button.
    SignalConnection update_conn;      ///< Connection to chart's sig_moved.
 public:
    explicit WScanResult(bool with_buttons = true);
    ~WScanResult();

    void setChart(WScannerChartWidget& achart);
    void update();
    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);
    void onResize(GfxRect oldSize, bool byLayout);

    int getScannedPlanetId(bool exact) const;
    int getScannedShipId() const;
    WScannerChartWidget* getChart() const;
};

/** Get scanned planet Id.
    \param exact=true    get Id of planet scanned exactly
    \param exact=false   get Id of planet whose gravity is scanned
    \return planet Id, 0 if none */
inline int
WScanResult::getScannedPlanetId(bool exact) const
{
    return exact ? xpid : gpid;
}

/** Get scanned ship Id.
    \return ship Id, 0 if none */
inline int
WScanResult::getScannedShipId() const
{
    return sid;
}

/** Get associated starchart widget. */
inline WScannerChartWidget*
WScanResult::getChart() const
{
    return chart;
}

#endif
